| rungweis | R Documentation |
Routine to run a GWEIS
rungweis(gweismem, bdinfo, snps, outfilename, maf = 0.01)
gweismem |
Models and memory allocated by gweis-mem to run the GWEIS. |
bdinfo |
Information about a Binary Dosage file that contains the genetic data to run the GWEIS |
snps |
List of SNPs in the Binary Dosage file to perform the GWEIS on. |
outfilename |
Name of the file to contain the output |
maf |
Minimum minor allele frequency of SNPs needed to run test on. |
Called for its side effect of writing tab-delimited results to
outfilename. Returns NULL invisibly.
## Not run:
bdinfo <- BinaryDosage::getbdinfo(system.file("extdata", "gendata.bdose",
package = "GxEScanR"))
subdata <- readRDS(system.file("extdata", "subdata.rds", package = "GxEScanR"))
subdata <- subdata[complete.cases(subdata), ]
subdata <- subdata[subdata$subid %in% bdinfo$samples$sid, ]
linearmodel <- glm(y_linear ~ x2 + x1, data = subdata)
linearmem <- gweis.mem(gemdl = linearmodel,
subids = subdata$subid,
tests = c("bg_ge", "bgxe", "joint"))
outfile <- tempfile(fileext = ".txt")
rungweis(gweismem = linearmem, bdinfo = bdinfo,
snps = 1:nrow(bdinfo$snps), outfilename = outfile)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.